'
'  RTFPRINT.BAS
'
'  Sample Program Written by Don Dickinson
'  Hereby public domain. Do with it as you wish.
'  No guarantee, use at your own risk.
'
'  Purpose:
'  1. Create a rich edit control
'  2. Fill a rich edit control with an .rtf file
'  3. Print the contents of a Rich Edit Control
'
'  Description:
'  Compiles to an EXE. Provides a rich text box
'  to enter text into. I suggest copying formatted
'  text out of MS Word and pasting in the box.
'

'
'  Compiler Directives
'
$DIM ALL
$COMPILE EXE
$OPTION VERSION4

'
'  Included files
'
$INCLUDE "WIN32API.INC"
$INCLUDE "COMDLG32.INC"
$INCLUDE "RICHEDIT.INC"
$INCLUDE "RTFFUNCT.BAS"

'
'  Globals and Constants
'
%txtRTF     = 101
%btnPrint   = 102

GLOBAL gInst      AS LONG
GLOBAL gMain      AS LONG
GLOBAL gBrush     AS LONG
GLOBAL gButton    AS LONG
GLOBAL gRTF       AS LONG
GLOBAL gRTFLib    AS LONG

'
'  WinMain
'
FUNCTION WinMain (BYVAL hInstance     AS LONG, _
                  BYVAL hPrevInstance AS LONG, _
                  lpCmdLine           AS ASCIIZ PTR, _
                  BYVAL iCmdShow      AS LONG) AS LONG

  LOCAL Msg         AS tagMsg
  LOCAL wndclass    AS WndClassEx
  LOCAL szClassName AS ASCIIZ * 80
  LOCAL hWnd        AS LONG
  LOCAL hMenu       AS LONG

  gInst                  = hInstance
  szClassName            = "DD_RTF_PRINTER"

  '- Has to be manually loaded and unloaded
  gRTFLib = LoadLibrary("RICHED32.DLL")

  '- Background brush
  gBrush = CreateSolidBrush (GetSysColor(%COLOR_BTNFACE))

  '- Register the window's class
  wndclass.cbSize        = SIZEOF(WndClass)
  wndclass.style         = %CS_HREDRAW OR %CS_VREDRAW
  wndclass.lpfnWndProc   = CODEPTR( WndProc )
  wndclass.cbClsExtra    = 0
  wndclass.cbWndExtra    = 0
  wndclass.hInstance     = hInstance
  wndclass.hIcon         = LoadIcon( hInstance, "PROGRAM" )
  wndclass.hCursor       = LoadCursor( %NULL, BYVAL %IDC_ARROW )
  wndclass.hbrBackground = gBrush
  wndclass.lpszMenuName  = %NULL
  wndclass.lpszClassName = VARPTR( szClassName )
  wndclass.hIconSm       = LoadIcon( hInstance, BYVAL %IDI_APPLICATION )

  RegisterClassEx wndclass

  ' Create a window using the registered class
  gMain = CreateWindow(szClassName, _               ' window class name
                          "RTF File Printer", _ ' window caption
                          %WS_OVERLAPPEDWINDOW, _      ' window style
                          100, _            ' initial x position
                          100, _            ' initial y position
                          470, _            ' initial x size
                          300, _            ' initial y size
                          %HWND_DESKTOP, _             ' parent window handle
                          hMenu, _                     ' window menu handle
                          hInstance, _                 ' program instance handle
                          BYVAL %NULL)                 ' creation parameters

  ShowWindow gMain, iCmdShow
  UpdateWindow gMain


  WHILE GetMessage(Msg, %NULL, 0, 0)
    TranslateMessage Msg
    DispatchMessage Msg
  WEND

  '- Clean up
  DeleteObject gBrush
  FreeLibrary gRTFLib

  FUNCTION = msg.wParam

END FUNCTION  ' WinMain


'
'  Procedure for main window
'
FUNCTION WndProc (BYVAL hWnd AS LONG, BYVAL wMsg AS LONG, _
                  BYVAL wParam AS LONG, BYVAL lParam AS LONG) EXPORT AS LONG

   Dim zString as ASCIIZ * 100
   DIm pzString as ASCIIZ PTR
   Dim foo as Long
   Dim a%
   Dim ptrData as ASCIIZ PTR

   SELECT CASE wMsg

      CASE %WM_CREATE

         SetCursor LoadCursor( %NULL, BYVAL %IDC_WAIT )
         foo= 0

         '- Create the listview control
         gRTF = CreateWindowEx(%WS_EX_CLIENTEDGE, _
               "RICHEDIT", "This is a test of some text in a rich edit box. I'm pretty sure that this text is long enough to wrap! You can call a file up by passing it on the command-line", _
               %WS_CHILD or %WS_VISIBLE or %ES_MULTILINE or _
               %ES_SUNKEN or %ES_SAVESEL or _
               %WS_HSCROLL or %WS_VSCROLL, _
               10, 60, 430, 200, hWnd, %txtRTF, gInst, foo)


         gButton = CreateWindow("button", "&Print", %WS_CHILD + %WS_VISIBLE, _
                   10, 10, 80, 40, hWnd, %btnPrint, gInst, 0)

         if command$ <> "" then
            if dir$(trim$(command$)) = "" then
               MsgBox "Unable to open rtf file: " + command$
            else
               SetRTFText gRTF, command$, %SF_RTF
            end if
         end if

         SetCursor LoadCursor( %NULL, BYVAL %IDC_ARROW )

      CASE %WM_COMMAND
         Select Case wParam
            Case %btnPrint
               PrintRichTextBox gMain, gInst, gRTF, 1.25, 1, 1.5, .75
               'SaveRTFText gRTF, "d:\test.rtf"
         End Select

      CASE %WM_PAINT
      CASE %WM_SIZE
      CASE %WM_DESTROY
         PostQuitMessage 0
         FUNCTION = 0
         EXIT FUNCTION

   END SELECT

   FUNCTION = DefWindowProc(hWnd, wMsg, wParam, lParam)

END FUNCTION


